@@ -32,12 +32,12 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             };
 
             use std::sync::Arc;
-            use checkout_core::dropshot as _;
+            use checkout_core::dropshot;
             use serde::{Deserialize, Serialize};
             use schemars::JsonSchema;
 
             pub struct ServerContext {
-                pub context_provider: #name
+                pub context_provider: super::#name
             }
 
             #[derive(Serialize, Deserialize, JsonSchema)]
